==> org-lsst-ccs-subsystem-fcs-gui-5.1.12-sources.jar: org/lsst/ccs/subsystems/fcs/carousel/ui/CarouselGeneralViewPanel.java <==

package org.lsst.ccs.subsystems.fcs.carousel.ui;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.SwingUtilities;
import org.lsst.ccs.bus.data.ConfigurationInfo;
import org.lsst.ccs.subsystems.fcs.FCSCst;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import static org.lsst.ccs.subsystems.fcs.FCSCst.NO_FILTER;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarousel;
import org.lsst.ccs.subsystems.fcs.ui.commons.DigitalSwitch;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.BIG_FONT;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.ZERO_VALUE;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.greenColor;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.insets_std;

/**
 * This view represents the carousel in a general design.
 * @author virieux
 */
public class CarouselGeneralViewPanel extends JPanel {
    private static final long serialVersionUID = 3579024322081964467L;
    
    private static final String NONE = "None";
    
    private InterfaceCarouselGUI subs;
    
    /*General Informations Panel (Configuration parameters)*/
    private final JPanel generalInfoPanel = new JPanel();
    private final JLabel speedLabel = new JLabel();
    
    /*Actual parameters (dynamic parameters */
    private final JPanel actualParametersPanel = new JPanel();
    private final JLabel homingLabel = new JLabel();
    private final JLabel actualPositionLabel = new JLabel();
    private final JLabel actualSpeedLabel = new JLabel();
    private final JLabel actualCurrentLabel = new JLabel();
    private final JLabel standbyLabel = new JLabel();
    private final DigitalSwitch standbySwitch = new DigitalSwitch();
    private final JLabel socketAtStandbyLabel = new JLabel();
    private final JLabel filterAtStandbyLabel = new JLabel();
    
    /*Carousel Disk*/
    private final CarouselDisk carouselDisk = new CarouselDisk();
    
    /*Control Panel*/
    private final JPanel controlPanel = new JPanel();
    private final JButton updatePositionButton = new JButton("Update Position");
    private final JButton rotateButton = new JButton("Rotate");

    public CarouselGeneralViewPanel() {
        initComponents();
    }

    protected void setSubsystem(InterfaceCarouselGUI subs) {
        this.subs = subs;
    }
    
    private void setDefaultValues() {
        speedLabel.setText(ZERO_VALUE);
        homingLabel.setText("NOT DONE");
        homingLabel.setForeground(Color.RED);
        actualPositionLabel.setText(ZERO_VALUE);
        actualSpeedLabel.setText(ZERO_VALUE);
        actualCurrentLabel.setText(ZERO_VALUE);
        standbyLabel.setText(FCSCst.NOT_AT_STANDBY);
        standbySwitch.setColor(Color.gray);
        socketAtStandbyLabel.setText(NONE);
        filterAtStandbyLabel.setText(NO_FILTER);
    }

    protected void initializeGui(ConfigurationInfo configInfo) {
        //here initialize this Panel from configInfo
    }
    
    protected void update(StatusDataPublishedByCarousel s) {
        FCSLOG.debug(getName() + " updating from carousel data:");
        SwingUtilities.invokeLater(new Update(s));
    }
    
    protected void update(String filterName, String socketName) {
        FCSLOG.debug(getName() + " updating from filter data:");
        SwingUtilities.invokeLater(new UpdateFilter(filterName, socketName));
    }    
    
    /**
     * A Runnable class to update this panel from an object StatusDataPublishedByCarousel.
     */
    public class Update implements Runnable {
        private final StatusDataPublishedByCarousel s;

        public Update(StatusDataPublishedByCarousel s) {
            this.s = s;
        }
        
        @Override
        public void run() {
            /*Update of actual parameters Panel*/
            if (s.isHomingDone()) {
                homingLabel.setText("DONE");
                homingLabel.setForeground(greenColor);
            } else {
                homingLabel.setText("TO_BE_DONE");
                homingLabel.setForeground(Color.RED);
            }
            actualPositionLabel.setText(Double.toString(s.getPosition()));
            actualSpeedLabel.setText(Double.toString(s.getVelocity()));
            actualCurrentLabel.setText(Double.toString(s.getCurrent()));
            if (s.isAtStandby()) {
                standbyLabel.setText(FCSCst.AT_STANDBY);
                standbySwitch.setColor(greenColor);
                socketAtStandbyLabel.setText(s.getSocketAtStandbyName());
                socketAtStandbyLabel.setFont(BIG_FONT);
                filterAtStandbyLabel.setText(s.getFilterAtStandbyName());
                filterAtStandbyLabel.setFont(BIG_FONT);
                
            } else {
                standbyLabel.setText(FCSCst.NOT_AT_STANDBY);
                standbySwitch.setColor(Color.orange);
                socketAtStandbyLabel.setText(s.getSocketAtStandbyName());
                filterAtStandbyLabel.setText(NONE);
            }
            
            carouselDisk.update(s);
        }
        
    }
    
    /**
     * A Runnable to update carouselDisk with data published by a filter.
     */
    public class UpdateFilter implements Runnable {
        
        private final String filterName;
        private final String socketName;

        public UpdateFilter(String filterName, String socketName) {
            this.filterName = filterName;
            this.socketName = socketName;
        }
        
        @Override
        public void run() {
                carouselDisk.update(filterName, socketName);
        }
    }    
    
    
    
    // <editor-fold defaultstate="collapsed" desc="Form Description">                          
    private void initComponents() {
        setName("carouselGeneralViewPanel");

        /**
         ******************************************************************************
         ** Buttons initialization
         * *****************************************************************************
         */
        updatePositionButton.addActionListener((ActionEvent evt) -> {
            updatePositionButtonActionPerformed(evt);
        });

        rotateButton.addActionListener((ActionEvent evt) -> {
            rotateButtonActionPerformed(evt);
        });
        
        /**
         ******************************************************************************
         ** end of Buttons initialization
         * *****************************************************************************
         */
        
        
        setDefaultValues();
        /**
         ******************************************************************************
         ** General Informations Panel
         * *****************************************************************************
         */
        generalInfoPanel.setBorder(BorderFactory.createTitledBorder("General Informations"));
        generalInfoPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc3 = new GridBagConstraints();
        gbc3.insets = insets_std;
        //first colomn
        gbc3.gridx = 0;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_START;

        generalInfoPanel.add(new JLabel("Maximum speed:"), gbc3);
        gbc3.gridy++;

        //second colomn
        gbc3.gridx++;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_END;
        generalInfoPanel.add(speedLabel, gbc3);
       
        /**
         ******************************************************************************
         ** end of General Informations Panel
         * *****************************************************************************
         */
        
        /**
         ******************************************************************************
         ** Actual Position Panel
         * *****************************************************************************
         */
        actualParametersPanel.setBorder(BorderFactory.createLineBorder(Color.yellow));
        actualParametersPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc1 = new GridBagConstraints();
        gbc1.insets = insets_std;
        //first colomn
        gbc1.gridx = 0;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_START;
        actualParametersPanel.add(new JLabel("Homing: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Position: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Speed: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Current: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(standbyLabel,gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Socket at STANDBY: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Filter at STANDBY: "),gbc1);
        //second colomn
        gbc1.gridx++;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_END;
        actualParametersPanel.add(homingLabel, gbc1);
        gbc1.gridy++;        
        actualParametersPanel.add(actualPositionLabel, gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(actualSpeedLabel, gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(actualCurrentLabel, gbc1);
        gbc1.gridy++;
        standbySwitch.setColor(Color.gray);
        actualParametersPanel.add(standbySwitch,gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(socketAtStandbyLabel,gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(filterAtStandbyLabel,gbc1);

        /**
         ******************************************************************************
         ** end of Actual Position Panel
         * *****************************************************************************
         */
        /**
         ******************************************************************************
         ** Control Panel
         * *****************************************************************************
         */
        controlPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc4 = new GridBagConstraints();
        gbc4.insets = insets_std; 
        gbc4.anchor = GridBagConstraints.FIRST_LINE_START;
        gbc4.fill = GridBagConstraints.HORIZONTAL;
        gbc4.gridx = 0;
        gbc4.gridy = 0;
        controlPanel.add(updatePositionButton, gbc4);
        gbc4.gridy++;
        controlPanel.add(rotateButton, gbc4);
        
        /**
         ******************************************************************************
         ** end of Control Panel
         * *****************************************************************************
         */        
        /**
         ******************************************************************************
         ** Whole Panel
         * *****************************************************************************
         */
        /*General Information Panel*/
        setBorder(BorderFactory.createTitledBorder("CAROUSEL GENERAL VIEW"));
        setLayout(new java.awt.GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.insets = insets_std;
        gbc.anchor = GridBagConstraints.CENTER;

        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.gridheight = 3;
        add(carouselDisk, gbc);
        gbc.gridheight = 1;
        
        gbc.gridx++;
        add(generalInfoPanel, gbc);
        
        gbc.gridy++;
        add(actualParametersPanel, gbc);
        
        gbc.gridy++;
        add(controlPanel, gbc);

        /**
         ******************************************************************************
         ** end of Whole Panel
         * *****************************************************************************
         */
    }
    
    private void updatePositionButtonActionPerformed(ActionEvent evt) {
        subs.updatePosition();
    }

    private void rotateButtonActionPerformed(ActionEvent evt) {
        subs.rotate();
    }    
    
    /**
     * Reset Panel to default values when subsystem is shutdown.
     */
    public void resetPanel() {
        setDefaultValues();
        carouselDisk.resetPanel();
    }
    
    @Override
    public String toString() {
        return "Carousel General View";
    }
    
    /**
     * Just to test the Panel.
     * @param argv 
     */
    public static void main(String[] argv) {

        CarouselGeneralViewPanel d = new CarouselGeneralViewPanel();
        JFrame frame = new JFrame("Test");
        frame.setContentPane(d);
        frame.pack();
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    }
    
}

==> org-lsst-ccs-subsystem-fcs-gui-5.3.6-sources.jar: org/lsst/ccs/subsystems/fcs/carousel/ui/CarouselGeneralViewPanel.java <==

package org.lsst.ccs.subsystems.fcs.carousel.ui;

import java.awt.Color;
import java.awt.GridBagConstraints;
import java.awt.GridBagLayout;
import java.awt.event.ActionEvent;
import javax.swing.BorderFactory;
import javax.swing.JButton;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JTextField;
import javax.swing.SwingUtilities;
import org.lsst.ccs.bus.data.ConfigurationInfo;
import static org.lsst.ccs.subsystems.fcs.FCSCst.FCSLOG;
import static org.lsst.ccs.subsystems.fcs.FCSCst.NO_FILTER;
import static org.lsst.ccs.subsystems.fcs.FCSCst.AT_STANDBY;
import static org.lsst.ccs.subsystems.fcs.FCSCst.NOT_AT_STANDBY;
import org.lsst.ccs.subsystems.fcs.StatusDataPublishedByCarousel;
import org.lsst.ccs.subsystems.fcs.ui.commons.DigitalSwitch;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.BIG_FONT;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.ZERO_VALUE;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.greenColor;
import static org.lsst.ccs.subsystems.fcs.ui.commons.Tools.insets_std;

/**
 * This view represents the carousel in a general design.
 * @author virieux
 */
public class CarouselGeneralViewPanel extends JPanel {
    private static final long serialVersionUID = 3579024322081964467L;

    private static final String NONE = "None";

    private InterfaceCarouselGUI subs;

    /*General Informations Panel (Configuration parameters)*/
    private final JPanel generalInfoPanel = new JPanel();
    private final JLabel speedLabel = new JLabel();

    /*Actual parameters (dynamic parameters */
    private final JPanel actualParametersPanel = new JPanel();
    private final JLabel homingLabel = new JLabel();
    private final JLabel actualPositionLabel = new JLabel();
    private final JLabel actualSpeedLabel = new JLabel();
    private final JLabel actualCurrentLabel = new JLabel();
    private final JLabel standbyLabel = new JLabel();
    private final DigitalSwitch standbySwitch = new DigitalSwitch();
    private final JLabel socketAtStandbyLabel = new JLabel();
    private final JLabel filterAtStandbyLabel = new JLabel();

    /*Carousel Disk*/
    private final CarouselDisk carouselDisk = new CarouselDisk();

    /*Control Panel*/
    private final JPanel controlPanel = new JPanel();
    private final JButton updatePositionButton = new JButton("Update Position");
    private final JButton rotateButton = new JButton("RotateSocketToStandby");
    private final JTextField socketNBField = new JTextField(1);
    private final JLabel socketLabel = new JLabel("enter socket nb:");
    /* socket to rotate at Standby */
    private int socketID;

    public CarouselGeneralViewPanel() {
        initComponents();
    }

    protected void setSubsystem(InterfaceCarouselGUI subs) {
        this.subs = subs;
    }

    private void setDefaultValues() {
        speedLabel.setText(ZERO_VALUE);
        homingLabel.setText("NOT DONE");
        homingLabel.setForeground(Color.RED);
        actualPositionLabel.setText(ZERO_VALUE);
        actualSpeedLabel.setText(ZERO_VALUE);
        actualCurrentLabel.setText(ZERO_VALUE);
        standbyLabel.setText(NOT_AT_STANDBY);
        standbySwitch.setColor(Color.gray);
        socketAtStandbyLabel.setText(NONE);
        filterAtStandbyLabel.setText(NO_FILTER);
    }

    protected void initializeGui(ConfigurationInfo configInfo) {
        //here initialize this Panel from configInfo
    }

    protected void update(StatusDataPublishedByCarousel s) {
        FCSLOG.debug(getName() + " updating from carousel data:");
        SwingUtilities.invokeLater(new Update(s));
    }

    protected void update(String filterName, String socketName) {
        FCSLOG.debug(getName() + " updating from filter data:");
        SwingUtilities.invokeLater(new UpdateFilter(filterName, socketName));
    }

    /**
     * A Runnable class to update this panel from an object StatusDataPublishedByCarousel.
     */
    public class Update implements Runnable {
        private final StatusDataPublishedByCarousel s;

        public Update(StatusDataPublishedByCarousel s) {
            this.s = s;
        }

        @Override
        public void run() {
            /*Update of actual parameters Panel*/
            if (s.isHomingDone()) {
                homingLabel.setText("DONE");
                homingLabel.setForeground(greenColor);
            } else {
                homingLabel.setText("TO_BE_DONE");
                homingLabel.setForeground(Color.RED);
            }
            actualPositionLabel.setText(Integer.toString(s.getPosition()));
            actualSpeedLabel.setText(Double.toString(s.getVelocity()));
            actualCurrentLabel.setText(Double.toString(s.getCurrent()));
            if (s.isAtStandby()) {
                standbyLabel.setText(AT_STANDBY);
                standbySwitch.setColor(greenColor);
                socketAtStandbyLabel.setText(s.getSocketAtStandbyName());
                socketAtStandbyLabel.setFont(BIG_FONT);
                filterAtStandbyLabel.setText(s.getFilterAtStandbyName());
                filterAtStandbyLabel.setFont(BIG_FONT);

            } else {
                standbyLabel.setText(NOT_AT_STANDBY);
                standbySwitch.setColor(Color.orange);
                socketAtStandbyLabel.setText(s.getSocketAtStandbyName());
                filterAtStandbyLabel.setText(NONE);
            }

            carouselDisk.update(s);
        }

    }

    /**
     * A Runnable to update carouselDisk with data published by a filter.
     */
    public class UpdateFilter implements Runnable {

        private final String filterName;
        private final String socketName;

        public UpdateFilter(String filterName, String socketName) {
            this.filterName = filterName;
            this.socketName = socketName;
        }

        @Override
        public void run() {
                carouselDisk.update(filterName, socketName);
        }
    }



    // <editor-fold defaultstate="collapsed" desc="Form Description">
    private void initComponents() {
        setName("carouselGeneralViewPanel");

        /**
         ******************************************************************************
         ** Buttons initialization
         * *****************************************************************************
         */
        updatePositionButton.addActionListener((ActionEvent evt) -> {
            updatePositionButtonActionPerformed(evt);
        });

        rotateButton.addActionListener((ActionEvent evt) -> {
            rotateButtonActionPerformed(evt);
        });

        socketNBField.addActionListener((ActionEvent evt) -> {
            socketNBFieldActionPerformed(evt);
        });


        /**
         ******************************************************************************
         ** end of Buttons initialization
         * *****************************************************************************
         */


        setDefaultValues();
        /**
         ******************************************************************************
         ** General Informations Panel
         * *****************************************************************************
         */
        generalInfoPanel.setBorder(BorderFactory.createTitledBorder("General Informations"));
        generalInfoPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc3 = new GridBagConstraints();
        gbc3.insets = insets_std;
        //first colomn
        gbc3.gridx = 0;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_START;

        generalInfoPanel.add(new JLabel("Maximum speed:"), gbc3);
        gbc3.gridy++;

        //second colomn
        gbc3.gridx++;
        gbc3.gridy = 0;
        gbc3.anchor = GridBagConstraints.LINE_END;
        generalInfoPanel.add(speedLabel, gbc3);

        /**
         ******************************************************************************
         ** end of General Informations Panel
         * *****************************************************************************
         */

        /**
         ******************************************************************************
         ** Actual Position Panel
         * *****************************************************************************
         */
        actualParametersPanel.setBorder(BorderFactory.createLineBorder(Color.yellow));
        actualParametersPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc1 = new GridBagConstraints();
        gbc1.insets = insets_std;
        //first colomn
        gbc1.gridx = 0;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_START;
        actualParametersPanel.add(new JLabel("Homing: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Position: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Speed: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Current: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(standbyLabel,gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Socket at STANDBY: "),gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(new JLabel("Filter at STANDBY: "),gbc1);
        //second colomn
        gbc1.gridx++;
        gbc1.gridy = 0;
        gbc1.anchor = GridBagConstraints.LINE_END;
        actualParametersPanel.add(homingLabel, gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(actualPositionLabel, gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(actualSpeedLabel, gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(actualCurrentLabel, gbc1);
        gbc1.gridy++;
        standbySwitch.setColor(Color.gray);
        actualParametersPanel.add(standbySwitch,gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(socketAtStandbyLabel,gbc1);
        gbc1.gridy++;
        actualParametersPanel.add(filterAtStandbyLabel,gbc1);

        /**
         ******************************************************************************
         ** end of Actual Position Panel
         * *****************************************************************************
         */
        /**
         ******************************************************************************
         ** Control Panel
         * *****************************************************************************
         */
        controlPanel.setLayout(new GridBagLayout());
        GridBagConstraints gbc4 = new GridBagConstraints();
        gbc4.insets = insets_std;
        gbc4.anchor = GridBagConstraints.FIRST_LINE_START;
        gbc4.fill = GridBagConstraints.HORIZONTAL;
        gbc4.gridx = 0;
        gbc4.gridy = 0;
        gbc4.gridwidth = 2;
        controlPanel.add(updatePositionButton, gbc4);
        gbc4.gridy++;
        gbc4.anchor = GridBagConstraints.EAST;
        gbc4.gridwidth = 1;
        controlPanel.add(socketLabel, gbc4);
        gbc4.gridx++;
        gbc4.anchor = GridBagConstraints.WEST;
        gbc4.fill = GridBagConstraints.NONE;
        controlPanel.add(socketNBField, gbc4);
        gbc4.gridy++;
        gbc4.gridx = 0;
        gbc4.gridwidth = 2;
        gbc4.fill = GridBagConstraints.HORIZONTAL;
        gbc4.anchor = GridBagConstraints.FIRST_LINE_START;
        controlPanel.add(rotateButton, gbc4);



        /**
         ******************************************************************************
         ** end of Control Panel
         * *****************************************************************************
         */
        /**
         ******************************************************************************
         ** Whole Panel
         * *****************************************************************************
         */
        /*General Information Panel*/
        setBorder(BorderFactory.createTitledBorder("CAROUSEL GENERAL VIEW"));
        setLayout(new java.awt.GridBagLayout());
        GridBagConstraints gbc = new GridBagConstraints();
        gbc.insets = insets_std;
        gbc.anchor = GridBagConstraints.CENTER;

        gbc.gridx = 0;
        gbc.gridy = 0;
        gbc.gridheight = 3;
        add(carouselDisk, gbc);
        gbc.gridheight = 1;

        gbc.gridx++;
        add(generalInfoPanel, gbc);

        gbc.gridy++;
        add(actualParametersPanel, gbc);

        gbc.gridy++;
        add(controlPanel, gbc);

        /**
         ******************************************************************************
         ** end of Whole Panel
         * *****************************************************************************
         */
    }

    private void updatePositionButtonActionPerformed(ActionEvent evt) {
        subs.updatePosition();
    }

    private void rotateButtonActionPerformed(ActionEvent evt) {
        subs.rotate(socketID);
    }

    private void socketNBFieldActionPerformed(ActionEvent evt) {
        this.socketID = Integer.parseInt(socketNBField.getText());
    }

    /**
     * Reset Panel to default values when subsystem is shutdown.
     */
    public void resetPanel() {
        setDefaultValues();
        carouselDisk.resetPanel();
    }

    @Override
    public String toString() {
        return "Carousel General View";
    }

    /**
     * Just to test the Panel.
     * @param argv
     */
    public static void main(String[] argv) {

        CarouselGeneralViewPanel d = new CarouselGeneralViewPanel();
        JFrame frame = new JFrame("Test");
        frame.setContentPane(d);
        frame.pack();
        frame.setVisible(true);
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);

    }

}
